import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import * as React from "react";
import { Positioner } from "./Positions";
import { Text } from "./Text";
import PropTypes from "prop-types";
import { isMobile } from "is-mobile";
import { useUid } from "./Hooks/use-uid";
import { useTheme } from "./Theme/Providers";
/** 手机或触摸屏幕 不需要使用 Tooltip，没法 :hover；
 * 用鼠标点击的场景才有意义。
 * Tooltip唯一儿子 需要传递 ref的。
 */
export const Tooltip = ({ placement, children, content, delayIn = 0, delayOut = 0, hover: enableHover = true, maxWidth = "300px", ...other }) => {
    const id = useUid();
    const theme = useTheme();
    const dark = theme.colors.mode === "dark";
    const [show, setShow] = React.useState(false);
    const [hovering, setHovering] = React.useState(false);
    const [delayShow, setDelayShow] = React.useState(false);
    function renderTrigger({ ref }) {
        // We don't want tooltips to show on touch based devices
        // so we just return the child without the event handlers.
        // Really not sure if this is the best way to do this.
        if (isMobile()) {
            return children;
        }
        const child = React.Children.only(children);
        // Enable on non-mobile devices
        return React.cloneElement(child, {
            ref,
            "aria-describedby": id,
            onMouseEnter: () => {
                if (!show)
                    setShow(true);
            },
            onMouseLeave: () => {
                if (show)
                    setShow(false);
            },
            onFocus: () => {
                if (!show)
                    setShow(true);
            },
            onBlur: () => {
                if (show)
                    setShow(false);
            }
        });
    }
    function onMouseLeave() {
        setHovering(false);
    }
    function onMouseEnter() {
        setHovering(true);
    }
    React.useEffect(() => {
        let timeoutIn;
        let timeoutOut;
        //延迟显示 延迟消失
        if (show) {
            timeoutIn = setTimeout(() => {
                setDelayShow(true);
            }, delayIn);
        }
        else {
            timeoutOut = setTimeout(() => {
                setDelayShow(false);
            }, delayOut);
        }
        return () => {
            if (timeoutIn) {
                clearInterval(timeoutIn);
            }
            if (timeoutOut) {
                clearInterval(timeoutOut);
            }
        };
    }, [delayIn, delayOut, show]);
    const bgColor = dark ? theme.colors.background.tint1 : theme.colors.palette.gray.dark;
    return (_jsx(Positioner, { placement: placement, isTip: true, bgColor: bgColor, isOpen: delayShow || (hovering && enableHover), target: renderTrigger, children: _jsx(Text, { className: "Tooltip__text", variant: "body", css: [
                {
                    fontSize: theme.fontSizes[0],
                    display: "inline-block",
                    margin: 0,
                    textAlign: "center",
                    maxWidth,
                    boxShadow: theme.shadows.md,
                    borderRadius: theme.radii.sm,
                    padding: `${theme.spaces.xs} ${theme.spaces.md}`,
                    color: "white",
                    background: dark
                        ? theme.colors.background.tint1
                        : theme.colors.palette.gray.dark
                }
            ], children: content }) }, id));
};
Tooltip.propTypes = {
    content: PropTypes.node.isRequired,
    children: PropTypes.node.isRequired,
    hover: PropTypes.bool,
    delayIn: PropTypes.number,
    delayOut: PropTypes.number,
    placement: PropTypes.oneOf([
        "auto-start",
        "auto",
        "auto-end",
        "top-start",
        "top",
        "top-end",
        "right-start",
        "right",
        "right-end",
        "bottom-end",
        "bottom",
        "bottom-start",
        "left-end",
        "left",
        "left-start"
    ])
};
//# sourceMappingURL=Tooltip.js.map